--[[
	Author:  Azmaedus US-Arathor
	Version: 0.1
	compatible with game version 6.0.3
	
	Change Log
	----------
	11/29/2014 - 0.1 - Creation of addon
	11/29/2014 - 0.1.1 - Support for tier 1, 2, and 3 garrison (Outpost, Fort, and Garrison) 
	
	Known Bugs
	----------
	ReloadUI doesn't trigger event to play music.
]]

-- Load the Ace libraries --
GarrisonJukeBox = LibStub("AceAddon-3.0"):NewAddon("GarrisonJukeBox", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

local gVersion = "0.1a"

local gMusicPlaying = false

-- Create the default settings for this addon --
local defaults = { 
    profile =  {
		shuffle = false,
		expac = nil,
		music = nil,
	},
}

local wowmusic = {
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni05.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni06.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni07r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni08r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarIntro01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni04.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni05.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni04.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni01r.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni04.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni05.mp3",
}

local maxmusic = table.getn(wowmusic)

-- Create the options variable to use in the config screen --
local options = {
	name = "Garrison JukeBox",
	handler = GarrisonJukeBox,
	type = "group",
	args = {
		shuffle = {
			type = "toggle",
			name = L["Shuffle"],
			desc = L["Randomly plays the music from your playlist."],

			set = function(info, value)
				-- Save variable
				GarrisonJukeBox.db.profile.shuffle = value
			end,

			get = function(info)
				return GarrisonJukeBox.db.profile.shuffle
			end,

			width = "full",
			order = 10,
		},
		expac = {
			type = "select",
			name = L["Expansion"],
			desc = L["Select the expansion."],
			style = "dropdown",
			values = {
				[1] = L["Vanilla"],
				[2] = L["Burning Crusade"],
				[3] = L["Wrath of the Lich King"],
				[4] = L["Cataclysm"],
				[5] = L["Mists of Pandaria"],
				[6] = L["Warlords of Dreanor"],
			},
			set = "SetExpac",
			get = "GetExpac",
			width = "normal",
			order = 10,
		},
		music = {
			type = "select",
			name = L["Music"],
			desc = L["Select the music."],
			style = "dropdown",
			values = {},
			set = "SetMusic",
			get = "GetMusic",
			width = "normal",
			order = 10,
		},
	},
}

-- Expac get/set functions
function GarrisonJukeBox:SetExpac(info, value)
	GarrisonJukeBox.db.profile.expac = value
end

function GarrisonJukeBox:GetExpac(info)
	return GarrisonJukeBox.db.profile.expac
end

-- Music get/set functions
function GarrisonJukeBox:SetMusic(info, value)
	GarrisonJukeBox.db.profile.music = value
end

function GarrisonJukeBox:GetMusic(info)
	return GarrisonJukeBox.db.profile.music
end

function GarrisonJukeBox:OnLoad(frame)
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED_NEW_AREA", "OnEvent2")
	GarrisonJukeBox:RegisterEvent("PLAYER_ENTERING_WORLD", "OnEvent2")
	GarrisonJukeBox:RegisterEvent("PLAYER_LOGIN", "OnEvent2")
	
	self:Print(L["Garrison JukeBox"] .. " " .. gVersion .. " " .. L["loaded!"])
end  

function GarrisonJukeBox:OnInitialize()
	GarrisonJukeBox.db = LibStub("AceDB-3.0"):New("GarrisonJukeBoxDB", defaults, "Default")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("GarrisonJukeBoxDB", options)
	  
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("GarrisonJukeBoxDB", "Garrison JukeBox")

	self:RegisterChatCommand("gjb", "ChatCommand")
	self:RegisterChatCommand("garrisonjukebox", "ChatCommand")
	  
	self:Print(L["Garrison JukeBox"] .. " " .. gVersion .. " " .. L["initialized!"])
end

function GarrisonJukeBox:OnEvent2(event, ...)
	if event == "ZONE_CHANGED_NEW_AREA" or event == "PLAYER_ENTERING_WORLD" or event == "PLAYER_ENTERING_WORLD" then
		ManageMusic(self)
	end
end

function ManageMusic(gjb)
	local mini = GetMinimapZoneText()

	s1, _ = string.find(mini, "'s Outpost", 1)
	s2, _ = string.find(mini, "'s Fort", 1)
	s3, _ = string.find(mini, "'s Garrison", 1)
	
	if s1 ~= nil or s2 ~= nil or s3 ~= nil then
		if gMusicPlaying == false then
			local id = random(1, maxmusic)
			StopMusic()
			PlayMusic(wowmusic[id])
			gjb:Print("Playing: " .. wowmusic[id])
			gMusicPlaying = true
		end
	else
		StopMusic()
		gMusicPlaying = false
	end
end

function GarrisonJukeBox:ChatCommand(input)
  -- Open dialog if no parameters, else do something with the parameters
  if not input or input:trim() == "" then
    InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
  else
    LibStub("AceConfigCmd-3.0").HandleCommand(SpamageMeters, "gjb", "GarrisonJukeBox", input)
  end
end
